==> alfred-ui-native-components-0.0.143.tgz: package/ui/molecules/sliders/continuousSlider/index.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { Slider } from '@miblanchard/react-native-slider';
import { ContinuousSliderModel } from '../sliderModels';
import { BooleanIconTrack } from '../../../atoms/track/booleanIconTrack';
import { styles } from '../styles';

export const ContinuousSlider: FC<ContinuousSliderModel> = ({
  ThumbComponent,
  IconLeft,
  IconRight,
  onStateChange,
  onFinishChange,
  defaultValue = 1,
  minValue,
  maxValue,
  isDisabled,
}) => {
  const [value, setValue] = useState<number>(defaultValue);

  const onFinishSlide = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    setValue(sliderValue);
    onFinishChange && onFinishChange(sliderValue);
  };

  const handleChangeValue = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    setValue(sliderValue);
  };

  useEffect(() => {
    setValue(defaultValue);
  }, [defaultValue]);

  useEffect(() => {
    onStateChange && onStateChange(value);
  }, [value]);

  return (
    <View testID={'ContinuousSlider'}>
      <BooleanIconTrack IconLeft={IconLeft} IconRight={IconRight} />
      <Slider
        disabled={isDisabled}
        animateTransitions
        renderThumbComponent={ThumbComponent}
        trackStyle={styles.sliderTrack}
        minimumTrackTintColor={'#FFFFFF00'}
        trackClickable={false}
        minimumValue={minValue}
        maximumValue={maxValue}
        value={value}
        onValueChange={handleChangeValue}
        onSlidingComplete={onFinishSlide}
        thumbTouchSize={{
          width: 40,
          height: 60,
        }}
      />
    </View>
  );
};

==> alfred-ui-native-components-0.0.159.tgz: package/ui/molecules/sliders/continuousSlider/index.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { Slider } from '@miblanchard/react-native-slider';
import { ContinuousSliderModel } from '../sliderModels';
import { BooleanIconTrack } from '../../../atoms/track/booleanIconTrack';
import { styles } from '../styles';

export const ContinuousSlider: FC<ContinuousSliderModel> = ({
  ThumbComponent,
  IconLeft,
  IconRight,
  onStateChange,
  onFinishChange,
  defaultValue = 1,
  minValue,
  maxValue,
  isDisabled,
}) => {
  const [value, setValue] = useState<number>(defaultValue);

  const onFinishSlide = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    setValue(sliderValue);
    onFinishChange && onFinishChange(sliderValue);
  };

  const handleChangeValue = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    setValue(sliderValue);
  };

  useEffect(() => {
    setValue(defaultValue);
  }, [defaultValue]);

  useEffect(() => {
    onStateChange && onStateChange(value);
  }, [value]);

  return (
    <View testID={'ContinuousSlider'}>
      <BooleanIconTrack IconLeft={IconLeft} IconRight={IconRight} />
      <Slider
        disabled={isDisabled}
        animateTransitions
        renderThumbComponent={ThumbComponent}
        trackStyle={styles().sliderTrack}
        minimumTrackTintColor={'#FFFFFF00'}
        trackClickable={false}
        minimumValue={minValue}
        maximumValue={maxValue}
        value={value}
        onValueChange={handleChangeValue}
        onSlidingComplete={onFinishSlide}
        thumbTouchSize={{
          width: 40,
          height: 60,
        }}
      />
    </View>
  );
};
